# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class EtcdBackup(pulumi.CustomResource):
    annotations: pulumi.Output[dict]
    """
    Annotations for Etcd Backup object (map)
    """
    backup_config: pulumi.Output[dict]
    """
    Backup config for etcd backup (list maxitems:1)

      * `enabled` (`bool`) - Enable etcd backup (bool)
      * `intervalHours` (`float`) - Interval hours for etcd backup. Default `12` (int)
      * `retention` (`float`) - Retention for etcd backup. Default `6` (int)
      * `s3BackupConfig` (`dict`) - S3 config options for etcd backup. Valid for `imported` and `rke` clusters. (list maxitems:1)
        * `access_key` (`str`) - Access key for S3 service (string)
        * `bucketName` (`str`) - Bucket name for S3 service (string)
        * `customCa` (`str`) - Base64 encoded custom CA for S3 service. Use filebase64(<FILE>) for encoding file. Available from Rancher v2.2.5 (string)
        * `endpoint` (`str`) - Endpoint for S3 service (string)
        * `folder` (`str`) - Folder for S3 service. Available from Rancher v2.2.7 (string)
        * `region` (`str`) - Region for S3 service (string)
        * `secret_key` (`str`) - Secret key for S3 service (string)

      * `safeTimestamp` (`bool`)
    """
    cluster_id: pulumi.Output[str]
    """
    Cluster ID to config Etcd Backup (string)
    """
    filename: pulumi.Output[str]
    """
    Filename of the Etcd Backup (string)
    """
    labels: pulumi.Output[dict]
    """
    Labels for Etcd Backup object (map)
    """
    manual: pulumi.Output[bool]
    """
    Manual execution of the Etcd Backup. Default `false` (bool)
    """
    name: pulumi.Output[str]
    """
    The name of the Etcd Backup (string)
    """
    namespace_id: pulumi.Output[str]
    """
    Description for the Etcd Backup (string)
    """
    def __init__(__self__, resource_name, opts=None, annotations=None, backup_config=None, cluster_id=None, filename=None, labels=None, manual=None, name=None, namespace_id=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a EtcdBackup resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: Annotations for Etcd Backup object (map)
        :param pulumi.Input[dict] backup_config: Backup config for etcd backup (list maxitems:1)
        :param pulumi.Input[str] cluster_id: Cluster ID to config Etcd Backup (string)
        :param pulumi.Input[str] filename: Filename of the Etcd Backup (string)
        :param pulumi.Input[dict] labels: Labels for Etcd Backup object (map)
        :param pulumi.Input[bool] manual: Manual execution of the Etcd Backup. Default `false` (bool)
        :param pulumi.Input[str] name: The name of the Etcd Backup (string)
        :param pulumi.Input[str] namespace_id: Description for the Etcd Backup (string)

        The **backup_config** object supports the following:

          * `enabled` (`pulumi.Input[bool]`) - Enable etcd backup (bool)
          * `intervalHours` (`pulumi.Input[float]`) - Interval hours for etcd backup. Default `12` (int)
          * `retention` (`pulumi.Input[float]`) - Retention for etcd backup. Default `6` (int)
          * `s3BackupConfig` (`pulumi.Input[dict]`) - S3 config options for etcd backup. Valid for `imported` and `rke` clusters. (list maxitems:1)
            * `access_key` (`pulumi.Input[str]`) - Access key for S3 service (string)
            * `bucketName` (`pulumi.Input[str]`) - Bucket name for S3 service (string)
            * `customCa` (`pulumi.Input[str]`) - Base64 encoded custom CA for S3 service. Use filebase64(<FILE>) for encoding file. Available from Rancher v2.2.5 (string)
            * `endpoint` (`pulumi.Input[str]`) - Endpoint for S3 service (string)
            * `folder` (`pulumi.Input[str]`) - Folder for S3 service. Available from Rancher v2.2.7 (string)
            * `region` (`pulumi.Input[str]`) - Region for S3 service (string)
            * `secret_key` (`pulumi.Input[str]`) - Secret key for S3 service (string)

          * `safeTimestamp` (`pulumi.Input[bool]`)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['annotations'] = annotations
            __props__['backup_config'] = backup_config
            if cluster_id is None:
                raise TypeError("Missing required property 'cluster_id'")
            __props__['cluster_id'] = cluster_id
            __props__['filename'] = filename
            __props__['labels'] = labels
            __props__['manual'] = manual
            __props__['name'] = name
            __props__['namespace_id'] = namespace_id
        super(EtcdBackup, __self__).__init__(
            'rancher2:index/etcdBackup:EtcdBackup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, annotations=None, backup_config=None, cluster_id=None, filename=None, labels=None, manual=None, name=None, namespace_id=None):
        """
        Get an existing EtcdBackup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: Annotations for Etcd Backup object (map)
        :param pulumi.Input[dict] backup_config: Backup config for etcd backup (list maxitems:1)
        :param pulumi.Input[str] cluster_id: Cluster ID to config Etcd Backup (string)
        :param pulumi.Input[str] filename: Filename of the Etcd Backup (string)
        :param pulumi.Input[dict] labels: Labels for Etcd Backup object (map)
        :param pulumi.Input[bool] manual: Manual execution of the Etcd Backup. Default `false` (bool)
        :param pulumi.Input[str] name: The name of the Etcd Backup (string)
        :param pulumi.Input[str] namespace_id: Description for the Etcd Backup (string)

        The **backup_config** object supports the following:

          * `enabled` (`pulumi.Input[bool]`) - Enable etcd backup (bool)
          * `intervalHours` (`pulumi.Input[float]`) - Interval hours for etcd backup. Default `12` (int)
          * `retention` (`pulumi.Input[float]`) - Retention for etcd backup. Default `6` (int)
          * `s3BackupConfig` (`pulumi.Input[dict]`) - S3 config options for etcd backup. Valid for `imported` and `rke` clusters. (list maxitems:1)
            * `access_key` (`pulumi.Input[str]`) - Access key for S3 service (string)
            * `bucketName` (`pulumi.Input[str]`) - Bucket name for S3 service (string)
            * `customCa` (`pulumi.Input[str]`) - Base64 encoded custom CA for S3 service. Use filebase64(<FILE>) for encoding file. Available from Rancher v2.2.5 (string)
            * `endpoint` (`pulumi.Input[str]`) - Endpoint for S3 service (string)
            * `folder` (`pulumi.Input[str]`) - Folder for S3 service. Available from Rancher v2.2.7 (string)
            * `region` (`pulumi.Input[str]`) - Region for S3 service (string)
            * `secret_key` (`pulumi.Input[str]`) - Secret key for S3 service (string)

          * `safeTimestamp` (`pulumi.Input[bool]`)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["annotations"] = annotations
        __props__["backup_config"] = backup_config
        __props__["cluster_id"] = cluster_id
        __props__["filename"] = filename
        __props__["labels"] = labels
        __props__["manual"] = manual
        __props__["name"] = name
        __props__["namespace_id"] = namespace_id
        return EtcdBackup(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class ClusterRoleTemplateBinding(pulumi.CustomResource):
    annotations: pulumi.Output[dict]
    """
    Annotations for cluster role template binding (map)
    """
    cluster_id: pulumi.Output[str]
    """
    The cluster id where bind cluster role template binding (string)
    """
    group_id: pulumi.Output[str]
    """
    The group ID to assign cluster role template binding (string)
    """
    group_principal_id: pulumi.Output[str]
    """
    The group_principal ID to assign cluster role template binding (string)
    """
    labels: pulumi.Output[dict]
    """
    Labels for cluster role template binding (map)
    """
    name: pulumi.Output[str]
    """
    The name of the cluster role template binding (string)
    """
    role_template_id: pulumi.Output[str]
    """
    The role template id from create cluster role template binding (string)
    """
    user_id: pulumi.Output[str]
    """
    The user ID to assign cluster role template binding (string)
    """
    user_principal_id: pulumi.Output[str]
    """
    The user_principal ID to assign cluster role template binding (string)
    """
    def __init__(__self__, resource_name, opts=None, annotations=None, cluster_id=None, group_id=None, group_principal_id=None, labels=None, name=None, role_template_id=None, user_id=None, user_principal_id=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Rancher v2 Cluster Role Template Binding resource. This can be used to create Cluster Role Template Bindings for Rancher v2 environments and retrieve their information.



        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: Annotations for cluster role template binding (map)
        :param pulumi.Input[str] cluster_id: The cluster id where bind cluster role template binding (string)
        :param pulumi.Input[str] group_id: The group ID to assign cluster role template binding (string)
        :param pulumi.Input[str] group_principal_id: The group_principal ID to assign cluster role template binding (string)
        :param pulumi.Input[dict] labels: Labels for cluster role template binding (map)
        :param pulumi.Input[str] name: The name of the cluster role template binding (string)
        :param pulumi.Input[str] role_template_id: The role template id from create cluster role template binding (string)
        :param pulumi.Input[str] user_id: The user ID to assign cluster role template binding (string)
        :param pulumi.Input[str] user_principal_id: The user_principal ID to assign cluster role template binding (string)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['annotations'] = annotations
            if cluster_id is None:
                raise TypeError("Missing required property 'cluster_id'")
            __props__['cluster_id'] = cluster_id
            __props__['group_id'] = group_id
            __props__['group_principal_id'] = group_principal_id
            __props__['labels'] = labels
            __props__['name'] = name
            if role_template_id is None:
                raise TypeError("Missing required property 'role_template_id'")
            __props__['role_template_id'] = role_template_id
            __props__['user_id'] = user_id
            __props__['user_principal_id'] = user_principal_id
        super(ClusterRoleTemplateBinding, __self__).__init__(
            'rancher2:index/clusterRoleTemplateBinding:ClusterRoleTemplateBinding',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, annotations=None, cluster_id=None, group_id=None, group_principal_id=None, labels=None, name=None, role_template_id=None, user_id=None, user_principal_id=None):
        """
        Get an existing ClusterRoleTemplateBinding resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: Annotations for cluster role template binding (map)
        :param pulumi.Input[str] cluster_id: The cluster id where bind cluster role template binding (string)
        :param pulumi.Input[str] group_id: The group ID to assign cluster role template binding (string)
        :param pulumi.Input[str] group_principal_id: The group_principal ID to assign cluster role template binding (string)
        :param pulumi.Input[dict] labels: Labels for cluster role template binding (map)
        :param pulumi.Input[str] name: The name of the cluster role template binding (string)
        :param pulumi.Input[str] role_template_id: The role template id from create cluster role template binding (string)
        :param pulumi.Input[str] user_id: The user ID to assign cluster role template binding (string)
        :param pulumi.Input[str] user_principal_id: The user_principal ID to assign cluster role template binding (string)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["annotations"] = annotations
        __props__["cluster_id"] = cluster_id
        __props__["group_id"] = group_id
        __props__["group_principal_id"] = group_principal_id
        __props__["labels"] = labels
        __props__["name"] = name
        __props__["role_template_id"] = role_template_id
        __props__["user_id"] = user_id
        __props__["user_principal_id"] = user_principal_id
        return ClusterRoleTemplateBinding(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class App(pulumi.CustomResource):
    annotations: pulumi.Output[dict]
    """
    Annotations for App object (map)
    """
    answers: pulumi.Output[dict]
    """
    Answers for the app template. If modified, app will be upgraded (map)
    """
    catalog_name: pulumi.Output[str]
    """
    Catalog name of the app. If modified, app will be upgraded. For use scoped catalogs:
    * add cluster ID before name, `c-XXXXX:<name>`
    * add project ID before name, `p-XXXXX:<name>`
    """
    description: pulumi.Output[str]
    """
    Description for the app (string)
    """
    external_id: pulumi.Output[str]
    """
    (Computed) The url of the app template on a catalog (string)
    """
    force_upgrade: pulumi.Output[bool]
    """
    Force app upgrade (string)
    """
    labels: pulumi.Output[dict]
    """
    Labels for App object (map)
    """
    name: pulumi.Output[str]
    """
    The name of the app (string)
    """
    project_id: pulumi.Output[str]
    """
    The project id where the app will be installed (string)
    """
    revision_id: pulumi.Output[str]
    """
    Current revision id for the app. If modified, If this argument is provided or modified, app will be rollbacked to `revision_id` (string)
    """
    target_namespace: pulumi.Output[str]
    """
    The namespace name where the app will be installed (string)
    """
    template_name: pulumi.Output[str]
    """
    Template name of the app. If modified, app will be upgraded (string)
    """
    template_version: pulumi.Output[str]
    """
    Template version of the app. If modified, app will be upgraded. Default: `latest` (string)
    """
    values_yaml: pulumi.Output[str]
    """
    values.yaml base64 encoded file content for the app template. If modified, app will be upgraded (string)
    """
    def __init__(__self__, resource_name, opts=None, annotations=None, answers=None, catalog_name=None, description=None, force_upgrade=None, labels=None, name=None, project_id=None, revision_id=None, target_namespace=None, template_name=None, template_version=None, values_yaml=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a App resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: Annotations for App object (map)
        :param pulumi.Input[dict] answers: Answers for the app template. If modified, app will be upgraded (map)
        :param pulumi.Input[str] catalog_name: Catalog name of the app. If modified, app will be upgraded. For use scoped catalogs:
               * add cluster ID before name, `c-XXXXX:<name>`
               * add project ID before name, `p-XXXXX:<name>`
        :param pulumi.Input[str] description: Description for the app (string)
        :param pulumi.Input[bool] force_upgrade: Force app upgrade (string)
        :param pulumi.Input[dict] labels: Labels for App object (map)
        :param pulumi.Input[str] name: The name of the app (string)
        :param pulumi.Input[str] project_id: The project id where the app will be installed (string)
        :param pulumi.Input[str] revision_id: Current revision id for the app. If modified, If this argument is provided or modified, app will be rollbacked to `revision_id` (string)
        :param pulumi.Input[str] target_namespace: The namespace name where the app will be installed (string)
        :param pulumi.Input[str] template_name: Template name of the app. If modified, app will be upgraded (string)
        :param pulumi.Input[str] template_version: Template version of the app. If modified, app will be upgraded. Default: `latest` (string)
        :param pulumi.Input[str] values_yaml: values.yaml base64 encoded file content for the app template. If modified, app will be upgraded (string)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['annotations'] = annotations
            __props__['answers'] = answers
            if catalog_name is None:
                raise TypeError("Missing required property 'catalog_name'")
            __props__['catalog_name'] = catalog_name
            __props__['description'] = description
            __props__['force_upgrade'] = force_upgrade
            __props__['labels'] = labels
            __props__['name'] = name
            if project_id is None:
                raise TypeError("Missing required property 'project_id'")
            __props__['project_id'] = project_id
            __props__['revision_id'] = revision_id
            if target_namespace is None:
                raise TypeError("Missing required property 'target_namespace'")
            __props__['target_namespace'] = target_namespace
            if template_name is None:
                raise TypeError("Missing required property 'template_name'")
            __props__['template_name'] = template_name
            __props__['template_version'] = template_version
            __props__['values_yaml'] = values_yaml
            __props__['external_id'] = None
        super(App, __self__).__init__(
            'rancher2:index/app:App',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, annotations=None, answers=None, catalog_name=None, description=None, external_id=None, force_upgrade=None, labels=None, name=None, project_id=None, revision_id=None, target_namespace=None, template_name=None, template_version=None, values_yaml=None):
        """
        Get an existing App resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: Annotations for App object (map)
        :param pulumi.Input[dict] answers: Answers for the app template. If modified, app will be upgraded (map)
        :param pulumi.Input[str] catalog_name: Catalog name of the app. If modified, app will be upgraded. For use scoped catalogs:
               * add cluster ID before name, `c-XXXXX:<name>`
               * add project ID before name, `p-XXXXX:<name>`
        :param pulumi.Input[str] description: Description for the app (string)
        :param pulumi.Input[str] external_id: (Computed) The url of the app template on a catalog (string)
        :param pulumi.Input[bool] force_upgrade: Force app upgrade (string)
        :param pulumi.Input[dict] labels: Labels for App object (map)
        :param pulumi.Input[str] name: The name of the app (string)
        :param pulumi.Input[str] project_id: The project id where the app will be installed (string)
        :param pulumi.Input[str] revision_id: Current revision id for the app. If modified, If this argument is provided or modified, app will be rollbacked to `revision_id` (string)
        :param pulumi.Input[str] target_namespace: The namespace name where the app will be installed (string)
        :param pulumi.Input[str] template_name: Template name of the app. If modified, app will be upgraded (string)
        :param pulumi.Input[str] template_version: Template version of the app. If modified, app will be upgraded. Default: `latest` (string)
        :param pulumi.Input[str] values_yaml: values.yaml base64 encoded file content for the app template. If modified, app will be upgraded (string)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["annotations"] = annotations
        __props__["answers"] = answers
        __props__["catalog_name"] = catalog_name
        __props__["description"] = description
        __props__["external_id"] = external_id
        __props__["force_upgrade"] = force_upgrade
        __props__["labels"] = labels
        __props__["name"] = name
        __props__["project_id"] = project_id
        __props__["revision_id"] = revision_id
        __props__["target_namespace"] = target_namespace
        __props__["template_name"] = template_name
        __props__["template_version"] = template_version
        __props__["values_yaml"] = values_yaml
        return App(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetCertificateResult:
    """
    A collection of values returned by getCertificate.
    """
    def __init__(__self__, annotations=None, certs=None, description=None, id=None, labels=None, name=None, namespace_id=None, project_id=None):
        if annotations and not isinstance(annotations, dict):
            raise TypeError("Expected argument 'annotations' to be a dict")
        __self__.annotations = annotations
        """
        (Computed) Annotations for certificate object (map)
        """
        if certs and not isinstance(certs, str):
            raise TypeError("Expected argument 'certs' to be a str")
        __self__.certs = certs
        """
        (Computed) Base64 encoded certs (string)
        """
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        __self__.description = description
        """
        (Computed) A certificate description (string)
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if labels and not isinstance(labels, dict):
            raise TypeError("Expected argument 'labels' to be a dict")
        __self__.labels = labels
        """
        (Computed) Labels for certificate object (map)
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if namespace_id and not isinstance(namespace_id, str):
            raise TypeError("Expected argument 'namespace_id' to be a str")
        __self__.namespace_id = namespace_id
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        __self__.project_id = project_id
class AwaitableGetCertificateResult(GetCertificateResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCertificateResult(
            annotations=self.annotations,
            certs=self.certs,
            description=self.description,
            id=self.id,
            labels=self.labels,
            name=self.name,
            namespace_id=self.namespace_id,
            project_id=self.project_id)

def get_certificate(name=None,namespace_id=None,project_id=None,opts=None):
    """
    Use this data source to retrieve information about a Rancher v2 certificate.

    Depending of the availability, there are 2 types of Rancher v2 certificates:
    - Project certificate: Available to all namespaces in the `project_id`
    - Namespaced certificate: Available to just `namespace_id` in the `project_id`




    :param str name: The name of the certificate (string)
    :param str namespace_id: The namespace id where to assign the namespaced certificate (string)
    :param str project_id: The project id where to assign the certificate (string)
    """
    __args__ = dict()


    __args__['name'] = name
    __args__['namespaceId'] = namespace_id
    __args__['projectId'] = project_id
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('rancher2:index/getCertificate:getCertificate', __args__, opts=opts).value

    return AwaitableGetCertificateResult(
        annotations=__ret__.get('annotations'),
        certs=__ret__.get('certs'),
        description=__ret__.get('description'),
        id=__ret__.get('id'),
        labels=__ret__.get('labels'),
        name=__ret__.get('name'),
        namespace_id=__ret__.get('namespaceId'),
        project_id=__ret__.get('projectId'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class AuthConfigFreeIpa(pulumi.CustomResource):
    access_mode: pulumi.Output[str]
    """
    Access mode for auth. `required`, `restricted`, `unrestricted` are supported. Default `unrestricted` (string)
    """
    allowed_principal_ids: pulumi.Output[list]
    """
    Allowed principal ids for auth. Required if `access_mode` is `required` or `restricted`. Ex: `freeipa_user://<DN>`  `freeipa_group://<DN>` (list)
    """
    annotations: pulumi.Output[dict]
    """
    Annotations of the resource (map)
    """
    certificate: pulumi.Output[str]
    """
    Base64 encoded CA certificate for TLS if self-signed. Use filebase64(<FILE>) for encoding file (string)
    """
    connection_timeout: pulumi.Output[float]
    """
    FreeIpa connection timeout. Default `5000` (int)
    """
    enabled: pulumi.Output[bool]
    """
    Enable auth config provider. Default `true` (bool)
    """
    group_dn_attribute: pulumi.Output[str]
    """
    Group DN attribute. Default `entryDN` (string)
    """
    group_member_mapping_attribute: pulumi.Output[str]
    """
    Group member mapping attribute. Default `member` (string)
    """
    group_member_user_attribute: pulumi.Output[str]
    """
    Group member user attribute. Default `entryDN` (string)
    """
    group_name_attribute: pulumi.Output[str]
    """
    Group name attribute. Default `cn` (string)
    """
    group_object_class: pulumi.Output[str]
    """
    Group object class. Default `groupOfNames` (string)
    """
    group_search_attribute: pulumi.Output[str]
    """
    Group search attribute. Default `cn` (string)
    """
    group_search_base: pulumi.Output[str]
    """
    Group search base (string)
    """
    labels: pulumi.Output[dict]
    """
    Labels of the resource (map)
    """
    name: pulumi.Output[str]
    """
    (Computed) The name of the resource (string)
    """
    nested_group_membership_enabled: pulumi.Output[bool]
    """
    Nested group membership enable. Default `false` (bool)
    """
    port: pulumi.Output[float]
    """
    FreeIpa port. Default `389` (int)
    """
    servers: pulumi.Output[list]
    """
    FreeIpa servers list (list)
    """
    service_account_distinguished_name: pulumi.Output[str]
    """
    Service account DN for access FreeIpa service (string)
    """
    service_account_password: pulumi.Output[str]
    """
    Service account password for access FreeIpa service (string)
    """
    tls: pulumi.Output[bool]
    """
    Enable TLS connection (bool)
    """
    type: pulumi.Output[str]
    """
    (Computed) The type of the resource (string)
    """
    user_disabled_bit_mask: pulumi.Output[float]
    """
    User disabled bit mask (int)
    """
    user_enabled_attribute: pulumi.Output[str]
    """
    User enable attribute (string)
    """
    user_login_attribute: pulumi.Output[str]
    """
    User login attribute. Default `uid` (string)
    """
    user_member_attribute: pulumi.Output[str]
    """
    User member attribute. Default `memberOf` (string)
    """
    user_name_attribute: pulumi.Output[str]
    """
    User name attribute. Default `givenName` (string)
    """
    user_object_class: pulumi.Output[str]
    """
    User object class. Default `inetorgperson` (string)
    """
    user_search_attribute: pulumi.Output[str]
    """
    User search attribute. Default `uid|sn|givenName` (string)
    """
    user_search_base: pulumi.Output[str]
    """
    User search base DN (string)
    """
    def __init__(__self__, resource_name, opts=None, access_mode=None, allowed_principal_ids=None, annotations=None, certificate=None, connection_timeout=None, enabled=None, group_dn_attribute=None, group_member_mapping_attribute=None, group_member_user_attribute=None, group_name_attribute=None, group_object_class=None, group_search_attribute=None, group_search_base=None, labels=None, nested_group_membership_enabled=None, port=None, servers=None, service_account_distinguished_name=None, service_account_password=None, tls=None, user_disabled_bit_mask=None, user_enabled_attribute=None, user_login_attribute=None, user_member_attribute=None, user_name_attribute=None, user_object_class=None, user_search_attribute=None, user_search_base=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Rancher v2 Auth Config FreeIpa resource. This can be used to configure and enable Auth Config FreeIpa for Rancher v2 RKE clusters and retrieve their information.

        In addition to the built-in local auth, only one external auth config provider can be enabled at a time.



        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_mode: Access mode for auth. `required`, `restricted`, `unrestricted` are supported. Default `unrestricted` (string)
        :param pulumi.Input[list] allowed_principal_ids: Allowed principal ids for auth. Required if `access_mode` is `required` or `restricted`. Ex: `freeipa_user://<DN>`  `freeipa_group://<DN>` (list)
        :param pulumi.Input[dict] annotations: Annotations of the resource (map)
        :param pulumi.Input[str] certificate: Base64 encoded CA certificate for TLS if self-signed. Use filebase64(<FILE>) for encoding file (string)
        :param pulumi.Input[float] connection_timeout: FreeIpa connection timeout. Default `5000` (int)
        :param pulumi.Input[bool] enabled: Enable auth config provider. Default `true` (bool)
        :param pulumi.Input[str] group_dn_attribute: Group DN attribute. Default `entryDN` (string)
        :param pulumi.Input[str] group_member_mapping_attribute: Group member mapping attribute. Default `member` (string)
        :param pulumi.Input[str] group_member_user_attribute: Group member user attribute. Default `entryDN` (string)
        :param pulumi.Input[str] group_name_attribute: Group name attribute. Default `cn` (string)
        :param pulumi.Input[str] group_object_class: Group object class. Default `groupOfNames` (string)
        :param pulumi.Input[str] group_search_attribute: Group search attribute. Default `cn` (string)
        :param pulumi.Input[str] group_search_base: Group search base (string)
        :param pulumi.Input[dict] labels: Labels of the resource (map)
        :param pulumi.Input[bool] nested_group_membership_enabled: Nested group membership enable. Default `false` (bool)
        :param pulumi.Input[float] port: FreeIpa port. Default `389` (int)
        :param pulumi.Input[list] servers: FreeIpa servers list (list)
        :param pulumi.Input[str] service_account_distinguished_name: Service account DN for access FreeIpa service (string)
        :param pulumi.Input[str] service_account_password: Service account password for access FreeIpa service (string)
        :param pulumi.Input[bool] tls: Enable TLS connection (bool)
        :param pulumi.Input[float] user_disabled_bit_mask: User disabled bit mask (int)
        :param pulumi.Input[str] user_enabled_attribute: User enable attribute (string)
        :param pulumi.Input[str] user_login_attribute: User login attribute. Default `uid` (string)
        :param pulumi.Input[str] user_member_attribute: User member attribute. Default `memberOf` (string)
        :param pulumi.Input[str] user_name_attribute: User name attribute. Default `givenName` (string)
        :param pulumi.Input[str] user_object_class: User object class. Default `inetorgperson` (string)
        :param pulumi.Input[str] user_search_attribute: User search attribute. Default `uid|sn|givenName` (string)
        :param pulumi.Input[str] user_search_base: User search base DN (string)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['access_mode'] = access_mode
            __props__['allowed_principal_ids'] = allowed_principal_ids
            __props__['annotations'] = annotations
            __props__['certificate'] = certificate
            __props__['connection_timeout'] = connection_timeout
            __props__['enabled'] = enabled
            __props__['group_dn_attribute'] = group_dn_attribute
            __props__['group_member_mapping_attribute'] = group_member_mapping_attribute
            __props__['group_member_user_attribute'] = group_member_user_attribute
            __props__['group_name_attribute'] = group_name_attribute
            __props__['group_object_class'] = group_object_class
            __props__['group_search_attribute'] = group_search_attribute
            __props__['group_search_base'] = group_search_base
            __props__['labels'] = labels
            __props__['nested_group_membership_enabled'] = nested_group_membership_enabled
            __props__['port'] = port
            if servers is None:
                raise TypeError("Missing required property 'servers'")
            __props__['servers'] = servers
            if service_account_distinguished_name is None:
                raise TypeError("Missing required property 'service_account_distinguished_name'")
            __props__['service_account_distinguished_name'] = service_account_distinguished_name
            if service_account_password is None:
                raise TypeError("Missing required property 'service_account_password'")
            __props__['service_account_password'] = service_account_password
            __props__['tls'] = tls
            __props__['user_disabled_bit_mask'] = user_disabled_bit_mask
            __props__['user_enabled_attribute'] = user_enabled_attribute
            __props__['user_login_attribute'] = user_login_attribute
            __props__['user_member_attribute'] = user_member_attribute
            __props__['user_name_attribute'] = user_name_attribute
            __props__['user_object_class'] = user_object_class
            __props__['user_search_attribute'] = user_search_attribute
            if user_search_base is None:
                raise TypeError("Missing required property 'user_search_base'")
            __props__['user_search_base'] = user_search_base
            __props__['name'] = None
            __props__['type'] = None
        super(AuthConfigFreeIpa, __self__).__init__(
            'rancher2:index/authConfigFreeIpa:AuthConfigFreeIpa',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, access_mode=None, allowed_principal_ids=None, annotations=None, certificate=None, connection_timeout=None, enabled=None, group_dn_attribute=None, group_member_mapping_attribute=None, group_member_user_attribute=None, group_name_attribute=None, group_object_class=None, group_search_attribute=None, group_search_base=None, labels=None, name=None, nested_group_membership_enabled=None, port=None, servers=None, service_account_distinguished_name=None, service_account_password=None, tls=None, type=None, user_disabled_bit_mask=None, user_enabled_attribute=None, user_login_attribute=None, user_member_attribute=None, user_name_attribute=None, user_object_class=None, user_search_attribute=None, user_search_base=None):
        """
        Get an existing AuthConfigFreeIpa resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_mode: Access mode for auth. `required`, `restricted`, `unrestricted` are supported. Default `unrestricted` (string)
        :param pulumi.Input[list] allowed_principal_ids: Allowed principal ids for auth. Required if `access_mode` is `required` or `restricted`. Ex: `freeipa_user://<DN>`  `freeipa_group://<DN>` (list)
        :param pulumi.Input[dict] annotations: Annotations of the resource (map)
        :param pulumi.Input[str] certificate: Base64 encoded CA certificate for TLS if self-signed. Use filebase64(<FILE>) for encoding file (string)
        :param pulumi.Input[float] connection_timeout: FreeIpa connection timeout. Default `5000` (int)
        :param pulumi.Input[bool] enabled: Enable auth config provider. Default `true` (bool)
        :param pulumi.Input[str] group_dn_attribute: Group DN attribute. Default `entryDN` (string)
        :param pulumi.Input[str] group_member_mapping_attribute: Group member mapping attribute. Default `member` (string)
        :param pulumi.Input[str] group_member_user_attribute: Group member user attribute. Default `entryDN` (string)
        :param pulumi.Input[str] group_name_attribute: Group name attribute. Default `cn` (string)
        :param pulumi.Input[str] group_object_class: Group object class. Default `groupOfNames` (string)
        :param pulumi.Input[str] group_search_attribute: Group search attribute. Default `cn` (string)
        :param pulumi.Input[str] group_search_base: Group search base (string)
        :param pulumi.Input[dict] labels: Labels of the resource (map)
        :param pulumi.Input[str] name: (Computed) The name of the resource (string)
        :param pulumi.Input[bool] nested_group_membership_enabled: Nested group membership enable. Default `false` (bool)
        :param pulumi.Input[float] port: FreeIpa port. Default `389` (int)
        :param pulumi.Input[list] servers: FreeIpa servers list (list)
        :param pulumi.Input[str] service_account_distinguished_name: Service account DN for access FreeIpa service (string)
        :param pulumi.Input[str] service_account_password: Service account password for access FreeIpa service (string)
        :param pulumi.Input[bool] tls: Enable TLS connection (bool)
        :param pulumi.Input[str] type: (Computed) The type of the resource (string)
        :param pulumi.Input[float] user_disabled_bit_mask: User disabled bit mask (int)
        :param pulumi.Input[str] user_enabled_attribute: User enable attribute (string)
        :param pulumi.Input[str] user_login_attribute: User login attribute. Default `uid` (string)
        :param pulumi.Input[str] user_member_attribute: User member attribute. Default `memberOf` (string)
        :param pulumi.Input[str] user_name_attribute: User name attribute. Default `givenName` (string)
        :param pulumi.Input[str] user_object_class: User object class. Default `inetorgperson` (string)
        :param pulumi.Input[str] user_search_attribute: User search attribute. Default `uid|sn|givenName` (string)
        :param pulumi.Input[str] user_search_base: User search base DN (string)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["access_mode"] = access_mode
        __props__["allowed_principal_ids"] = allowed_principal_ids
        __props__["annotations"] = annotations
        __props__["certificate"] = certificate
        __props__["connection_timeout"] = connection_timeout
        __props__["enabled"] = enabled
        __props__["group_dn_attribute"] = group_dn_attribute
        __props__["group_member_mapping_attribute"] = group_member_mapping_attribute
        __props__["group_member_user_attribute"] = group_member_user_attribute
        __props__["group_name_attribute"] = group_name_attribute
        __props__["group_object_class"] = group_object_class
        __props__["group_search_attribute"] = group_search_attribute
        __props__["group_search_base"] = group_search_base
        __props__["labels"] = labels
        __props__["name"] = name
        __props__["nested_group_membership_enabled"] = nested_group_membership_enabled
        __props__["port"] = port
        __props__["servers"] = servers
        __props__["service_account_distinguished_name"] = service_account_distinguished_name
        __props__["service_account_password"] = service_account_password
        __props__["tls"] = tls
        __props__["type"] = type
        __props__["user_disabled_bit_mask"] = user_disabled_bit_mask
        __props__["user_enabled_attribute"] = user_enabled_attribute
        __props__["user_login_attribute"] = user_login_attribute
        __props__["user_member_attribute"] = user_member_attribute
        __props__["user_name_attribute"] = user_name_attribute
        __props__["user_object_class"] = user_object_class
        __props__["user_search_attribute"] = user_search_attribute
        __props__["user_search_base"] = user_search_base
        return AuthConfigFreeIpa(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class Catalog(pulumi.CustomResource):
    annotations: pulumi.Output[dict]
    """
    Annotations for the catalog (map)
    """
    branch: pulumi.Output[str]
    """
    The branch of the catalog repo to use. Default `master` (string)
    """
    cluster_id: pulumi.Output[str]
    """
    The cluster id of the catalog. Mandatory if `scope = cluster` (string)
    """
    description: pulumi.Output[str]
    """
    A catalog description (string)
    """
    kind: pulumi.Output[str]
    """
    The kind of the catalog. Just helm by the moment (string)
    """
    labels: pulumi.Output[dict]
    """
    Labels for the catalog (map)
    """
    name: pulumi.Output[str]
    """
    The name of the catalog (string)
    """
    password: pulumi.Output[str]
    """
    The password to access the catalog if needed (string)
    """
    project_id: pulumi.Output[str]
    """
    The project id of the catalog. Mandatory if `scope = project` (string)
    """
    refresh: pulumi.Output[bool]
    """
    Catalog will wait for refresh after tf creation and on every tf read. Default `false` (bool)
    """
    scope: pulumi.Output[str]
    """
    The scope of the catalog. `cluster`, `global`, and `project` are supported. Default `global` (string)
    """
    url: pulumi.Output[str]
    """
    The url of the catalog repo (string)
    """
    username: pulumi.Output[str]
    """
    The username to access the catalog if needed (string)
    """
    version: pulumi.Output[str]
    """
    Helm version for the catalog. Available options: `helm_v2` and `helm_v3` (string)
    """
    def __init__(__self__, resource_name, opts=None, annotations=None, branch=None, cluster_id=None, description=None, kind=None, labels=None, name=None, password=None, project_id=None, refresh=None, scope=None, url=None, username=None, version=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Rancher v2 Catalog resource. This can be used to create cluster, global and/or project catalogs for Rancher v2 environments and retrieve their information.



        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: Annotations for the catalog (map)
        :param pulumi.Input[str] branch: The branch of the catalog repo to use. Default `master` (string)
        :param pulumi.Input[str] cluster_id: The cluster id of the catalog. Mandatory if `scope = cluster` (string)
        :param pulumi.Input[str] description: A catalog description (string)
        :param pulumi.Input[str] kind: The kind of the catalog. Just helm by the moment (string)
        :param pulumi.Input[dict] labels: Labels for the catalog (map)
        :param pulumi.Input[str] name: The name of the catalog (string)
        :param pulumi.Input[str] password: The password to access the catalog if needed (string)
        :param pulumi.Input[str] project_id: The project id of the catalog. Mandatory if `scope = project` (string)
        :param pulumi.Input[bool] refresh: Catalog will wait for refresh after tf creation and on every tf read. Default `false` (bool)
        :param pulumi.Input[str] scope: The scope of the catalog. `cluster`, `global`, and `project` are supported. Default `global` (string)
        :param pulumi.Input[str] url: The url of the catalog repo (string)
        :param pulumi.Input[str] username: The username to access the catalog if needed (string)
        :param pulumi.Input[str] version: Helm version for the catalog. Available options: `helm_v2` and `helm_v3` (string)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['annotations'] = annotations
            __props__['branch'] = branch
            __props__['cluster_id'] = cluster_id
            __props__['description'] = description
            __props__['kind'] = kind
            __props__['labels'] = labels
            __props__['name'] = name
            __props__['password'] = password
            __props__['project_id'] = project_id
            __props__['refresh'] = refresh
            __props__['scope'] = scope
            if url is None:
                raise TypeError("Missing required property 'url'")
            __props__['url'] = url
            __props__['username'] = username
            __props__['version'] = version
        super(Catalog, __self__).__init__(
            'rancher2:index/catalog:Catalog',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, annotations=None, branch=None, cluster_id=None, description=None, kind=None, labels=None, name=None, password=None, project_id=None, refresh=None, scope=None, url=None, username=None, version=None):
        """
        Get an existing Catalog resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] annotations: Annotations for the catalog (map)
        :param pulumi.Input[str] branch: The branch of the catalog repo to use. Default `master` (string)
        :param pulumi.Input[str] cluster_id: The cluster id of the catalog. Mandatory if `scope = cluster` (string)
        :param pulumi.Input[str] description: A catalog description (string)
        :param pulumi.Input[str] kind: The kind of the catalog. Just helm by the moment (string)
        :param pulumi.Input[dict] labels: Labels for the catalog (map)
        :param pulumi.Input[str] name: The name of the catalog (string)
        :param pulumi.Input[str] password: The password to access the catalog if needed (string)
        :param pulumi.Input[str] project_id: The project id of the catalog. Mandatory if `scope = project` (string)
        :param pulumi.Input[bool] refresh: Catalog will wait for refresh after tf creation and on every tf read. Default `false` (bool)
        :param pulumi.Input[str] scope: The scope of the catalog. `cluster`, `global`, and `project` are supported. Default `global` (string)
        :param pulumi.Input[str] url: The url of the catalog repo (string)
        :param pulumi.Input[str] username: The username to access the catalog if needed (string)
        :param pulumi.Input[str] version: Helm version for the catalog. Available options: `helm_v2` and `helm_v3` (string)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["annotations"] = annotations
        __props__["branch"] = branch
        __props__["cluster_id"] = cluster_id
        __props__["description"] = description
        __props__["kind"] = kind
        __props__["labels"] = labels
        __props__["name"] = name
        __props__["password"] = password
        __props__["project_id"] = project_id
        __props__["refresh"] = refresh
        __props__["scope"] = scope
        __props__["url"] = url
        __props__["username"] = username
        __props__["version"] = version
        return Catalog(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetAppResult:
    """
    A collection of values returned by getApp.
    """
    def __init__(__self__, annotations=None, answers=None, catalog_name=None, description=None, external_id=None, id=None, labels=None, name=None, project_id=None, revision_id=None, target_namespace=None, template_name=None, template_version=None, values_yaml=None):
        if annotations and not isinstance(annotations, dict):
            raise TypeError("Expected argument 'annotations' to be a dict")
        __self__.annotations = annotations
        """
        (Computed) Annotations for the catalog (map)
        """
        if answers and not isinstance(answers, dict):
            raise TypeError("Expected argument 'answers' to be a dict")
        __self__.answers = answers
        """
        (Computed) Answers for the app (map)
        """
        if catalog_name and not isinstance(catalog_name, str):
            raise TypeError("Expected argument 'catalog_name' to be a str")
        __self__.catalog_name = catalog_name
        """
        (Computed) Catalog name of the app (string)
        """
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        __self__.description = description
        """
        (Computed) Description for the app (string)
        """
        if external_id and not isinstance(external_id, str):
            raise TypeError("Expected argument 'external_id' to be a str")
        __self__.external_id = external_id
        """
        (Computed) The URL of the helm catalog app (string)
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if labels and not isinstance(labels, dict):
            raise TypeError("Expected argument 'labels' to be a dict")
        __self__.labels = labels
        """
        (Computed) Labels for the catalog (map)
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        __self__.project_id = project_id
        if revision_id and not isinstance(revision_id, str):
            raise TypeError("Expected argument 'revision_id' to be a str")
        __self__.revision_id = revision_id
        """
        (Computed) Current revision id for the app (string)
        """
        if target_namespace and not isinstance(target_namespace, str):
            raise TypeError("Expected argument 'target_namespace' to be a str")
        __self__.target_namespace = target_namespace
        if template_name and not isinstance(template_name, str):
            raise TypeError("Expected argument 'template_name' to be a str")
        __self__.template_name = template_name
        """
        (Computed) Template name of the app (string)
        """
        if template_version and not isinstance(template_version, str):
            raise TypeError("Expected argument 'template_version' to be a str")
        __self__.template_version = template_version
        """
        (Computed) Template version of the app (string)
        """
        if values_yaml and not isinstance(values_yaml, str):
            raise TypeError("Expected argument 'values_yaml' to be a str")
        __self__.values_yaml = values_yaml
        """
        (Computed) values.yaml base64 encoded file content for the app (string)
        """
class AwaitableGetAppResult(GetAppResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAppResult(
            annotations=self.annotations,
            answers=self.answers,
            catalog_name=self.catalog_name,
            description=self.description,
            external_id=self.external_id,
            id=self.id,
            labels=self.labels,
            name=self.name,
            project_id=self.project_id,
            revision_id=self.revision_id,
            target_namespace=self.target_namespace,
            template_name=self.template_name,
            template_version=self.template_version,
            values_yaml=self.values_yaml)

def get_app(annotations=None,name=None,project_id=None,target_namespace=None,opts=None):
    """
    Use this data source to retrieve information about a Rancher v2 app.




    :param dict annotations: (Computed) Annotations for the catalog (map)
    :param str name: The app name (string)
    :param str project_id: The id of the project where the app is deployed (string)
    :param str target_namespace: The namespace name where the app is deployed (string)
    """
    __args__ = dict()


    __args__['annotations'] = annotations
    __args__['name'] = name
    __args__['projectId'] = project_id
    __args__['targetNamespace'] = target_namespace
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('rancher2:index/getApp:getApp', __args__, opts=opts).value

    return AwaitableGetAppResult(
        annotations=__ret__.get('annotations'),
        answers=__ret__.get('answers'),
        catalog_name=__ret__.get('catalogName'),
        description=__ret__.get('description'),
        external_id=__ret__.get('externalId'),
        id=__ret__.get('id'),
        labels=__ret__.get('labels'),
        name=__ret__.get('name'),
        project_id=__ret__.get('projectId'),
        revision_id=__ret__.get('revisionId'),
        target_namespace=__ret__.get('targetNamespace'),
        template_name=__ret__.get('templateName'),
        template_version=__ret__.get('templateVersion'),
        values_yaml=__ret__.get('valuesYaml'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class ClusterSync(pulumi.CustomResource):
    cluster_id: pulumi.Output[str]
    """
    The cluster ID that is syncing (string)
    """
    default_project_id: pulumi.Output[str]
    """
    (Computed) Default project ID for the cluster sync (string)
    """
    kube_config: pulumi.Output[str]
    """
    (Computed/Sensitive) Kube Config generated for the cluster sync (string)
    """
    node_pool_ids: pulumi.Output[list]
    """
    The node pool IDs used by the cluster id (list)
    """
    synced: pulumi.Output[bool]
    system_project_id: pulumi.Output[str]
    """
    (Computed) System project ID for the cluster sync (string)
    """
    wait_monitoring: pulumi.Output[bool]
    """
    Wait until monitoring is up and running. Default: `false` (bool)
    """
    def __init__(__self__, resource_name, opts=None, cluster_id=None, node_pool_ids=None, synced=None, wait_monitoring=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a ClusterSync resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cluster_id: The cluster ID that is syncing (string)
        :param pulumi.Input[list] node_pool_ids: The node pool IDs used by the cluster id (list)
        :param pulumi.Input[bool] wait_monitoring: Wait until monitoring is up and running. Default: `false` (bool)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if cluster_id is None:
                raise TypeError("Missing required property 'cluster_id'")
            __props__['cluster_id'] = cluster_id
            __props__['node_pool_ids'] = node_pool_ids
            __props__['synced'] = synced
            __props__['wait_monitoring'] = wait_monitoring
            __props__['default_project_id'] = None
            __props__['kube_config'] = None
            __props__['system_project_id'] = None
        super(ClusterSync, __self__).__init__(
            'rancher2:index/clusterSync:ClusterSync',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, cluster_id=None, default_project_id=None, kube_config=None, node_pool_ids=None, synced=None, system_project_id=None, wait_monitoring=None):
        """
        Get an existing ClusterSync resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cluster_id: The cluster ID that is syncing (string)
        :param pulumi.Input[str] default_project_id: (Computed) Default project ID for the cluster sync (string)
        :param pulumi.Input[str] kube_config: (Computed/Sensitive) Kube Config generated for the cluster sync (string)
        :param pulumi.Input[list] node_pool_ids: The node pool IDs used by the cluster id (list)
        :param pulumi.Input[str] system_project_id: (Computed) System project ID for the cluster sync (string)
        :param pulumi.Input[bool] wait_monitoring: Wait until monitoring is up and running. Default: `false` (bool)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["cluster_id"] = cluster_id
        __props__["default_project_id"] = default_project_id
        __props__["kube_config"] = kube_config
        __props__["node_pool_ids"] = node_pool_ids
        __props__["synced"] = synced
        __props__["system_project_id"] = system_project_id
        __props__["wait_monitoring"] = wait_monitoring
        return ClusterSync(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetUserResult:
    """
    A collection of values returned by getUser.
    """
    def __init__(__self__, annotations=None, enabled=None, id=None, is_external=None, labels=None, name=None, principal_ids=None, username=None):
        if annotations and not isinstance(annotations, dict):
            raise TypeError("Expected argument 'annotations' to be a dict")
        __self__.annotations = annotations
        """
        (Computed) Annotations of the resource (map)
        """
        if enabled and not isinstance(enabled, bool):
            raise TypeError("Expected argument 'enabled' to be a bool")
        __self__.enabled = enabled
        """
        (Computed) The user is enabled (bool)
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if is_external and not isinstance(is_external, bool):
            raise TypeError("Expected argument 'is_external' to be a bool")
        __self__.is_external = is_external
        if labels and not isinstance(labels, dict):
            raise TypeError("Expected argument 'labels' to be a dict")
        __self__.labels = labels
        """
        (Computed) Labels of the resource (map)
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        """
        (Computed) The user common name (string)
        """
        if principal_ids and not isinstance(principal_ids, list):
            raise TypeError("Expected argument 'principal_ids' to be a list")
        __self__.principal_ids = principal_ids
        """
        (Computed) The user principal IDs (list)
        """
        if username and not isinstance(username, str):
            raise TypeError("Expected argument 'username' to be a str")
        __self__.username = username
class AwaitableGetUserResult(GetUserResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUserResult(
            annotations=self.annotations,
            enabled=self.enabled,
            id=self.id,
            is_external=self.is_external,
            labels=self.labels,
            name=self.name,
            principal_ids=self.principal_ids,
            username=self.username)

def get_user(is_external=None,name=None,username=None,opts=None):
    """
    Use this data source to retrieve information about a Rancher v2 user




    :param bool is_external: Set is the user if the user is external. Default: `false` (bool)
    :param str name: The name of the user (string)
    :param str username: The username of the user (string)
    """
    __args__ = dict()


    __args__['isExternal'] = is_external
    __args__['name'] = name
    __args__['username'] = username
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('rancher2:index/getUser:getUser', __args__, opts=opts).value

    return AwaitableGetUserResult(
        annotations=__ret__.get('annotations'),
        enabled=__ret__.get('enabled'),
        id=__ret__.get('id'),
        is_external=__ret__.get('isExternal'),
        labels=__ret__.get('labels'),
        name=__ret__.get('name'),
        principal_ids=__ret__.get('principalIds'),
        username=__ret__.get('username'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetClusterResult:
    """
    A collection of values returned by getCluster.
    """
    def __init__(__self__, aks_config=None, annotations=None, cluster_auth_endpoint=None, cluster_monitoring_input=None, cluster_registration_token=None, cluster_template_answers=None, cluster_template_id=None, cluster_template_questions=None, cluster_template_revision_id=None, default_pod_security_policy_template_id=None, default_project_id=None, description=None, driver=None, eks_config=None, enable_cluster_alerting=None, enable_cluster_monitoring=None, enable_network_policy=None, gke_config=None, id=None, k3s_config=None, kube_config=None, labels=None, name=None, rke_config=None, scheduled_cluster_scans=None, system_project_id=None):
        if aks_config and not isinstance(aks_config, dict):
            raise TypeError("Expected argument 'aks_config' to be a dict")
        __self__.aks_config = aks_config
        """
        (Computed) The Azure aks configuration for `aks` Clusters. Conflicts with `eks_config`, `gke_config` and `rke_config` (list maxitems:1)
        """
        if annotations and not isinstance(annotations, dict):
            raise TypeError("Expected argument 'annotations' to be a dict")
        __self__.annotations = annotations
        """
        (Computed) Annotations for Node Pool object (map)
        """
        if cluster_auth_endpoint and not isinstance(cluster_auth_endpoint, dict):
            raise TypeError("Expected argument 'cluster_auth_endpoint' to be a dict")
        __self__.cluster_auth_endpoint = cluster_auth_endpoint
        """
        (Computed) Enabling the [local cluster authorized endpoint](https://rancher.com/docs/rancher/v2.x/en/cluster-provisioning/rke-clusters/options/#local-cluster-auth-endpoint) allows direct communication with the cluster, bypassing the Rancher API proxy. (list maxitems:1)
        """
        if cluster_monitoring_input and not isinstance(cluster_monitoring_input, dict):
            raise TypeError("Expected argument 'cluster_monitoring_input' to be a dict")
        __self__.cluster_monitoring_input = cluster_monitoring_input
        """
        (Computed) Cluster monitoring config (list maxitems:1)
        """
        if cluster_registration_token and not isinstance(cluster_registration_token, dict):
            raise TypeError("Expected argument 'cluster_registration_token' to be a dict")
        __self__.cluster_registration_token = cluster_registration_token
        """
        (Computed) Cluster Registration Token generated for the cluster (list maxitems:1)
        """
        if cluster_template_answers and not isinstance(cluster_template_answers, dict):
            raise TypeError("Expected argument 'cluster_template_answers' to be a dict")
        __self__.cluster_template_answers = cluster_template_answers
        """
        (Computed) Cluster template answers (list maxitems:1)
        """
        if cluster_template_id and not isinstance(cluster_template_id, str):
            raise TypeError("Expected argument 'cluster_template_id' to be a str")
        __self__.cluster_template_id = cluster_template_id
        """
        (Computed) Cluster template ID (string)
        """
        if cluster_template_questions and not isinstance(cluster_template_questions, list):
            raise TypeError("Expected argument 'cluster_template_questions' to be a list")
        __self__.cluster_template_questions = cluster_template_questions
        """
        (Computed) Cluster template questions (list)
        """
        if cluster_template_revision_id and not isinstance(cluster_template_revision_id, str):
            raise TypeError("Expected argument 'cluster_template_revision_id' to be a str")
        __self__.cluster_template_revision_id = cluster_template_revision_id
        """
        (Computed) Cluster template revision ID (string)
        """
        if default_pod_security_policy_template_id and not isinstance(default_pod_security_policy_template_id, str):
            raise TypeError("Expected argument 'default_pod_security_policy_template_id' to be a str")
        __self__.default_pod_security_policy_template_id = default_pod_security_policy_template_id
        """
        (Optional/Computed) [Default pod security policy template id](https://rancher.com/docs/rancher/v2.x/en/cluster-provisioning/rke-clusters/options/#pod-security-policy-support) (string)
        """
        if default_project_id and not isinstance(default_project_id, str):
            raise TypeError("Expected argument 'default_project_id' to be a str")
        __self__.default_project_id = default_project_id
        """
        (Computed) Default project ID for the cluster (string)
        """
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        __self__.description = description
        """
        (Computed) The description for Cluster (string)
        """
        if driver and not isinstance(driver, str):
            raise TypeError("Expected argument 'driver' to be a str")
        __self__.driver = driver
        """
        (Computed) The driver used for the Cluster. `imported`, `azurekubernetesservice`, `amazonelasticcontainerservice`, `googlekubernetesengine` and `rancherKubernetesEngine` are supported (string)
        """
        if eks_config and not isinstance(eks_config, dict):
            raise TypeError("Expected argument 'eks_config' to be a dict")
        __self__.eks_config = eks_config
        """
        (Computed) The Amazon eks configuration for `eks` Clusters. Conflicts with `aks_config`, `gke_config` and `rke_config` (list maxitems:1)
        """
        if enable_cluster_alerting and not isinstance(enable_cluster_alerting, bool):
            raise TypeError("Expected argument 'enable_cluster_alerting' to be a bool")
        __self__.enable_cluster_alerting = enable_cluster_alerting
        if enable_cluster_monitoring and not isinstance(enable_cluster_monitoring, bool):
            raise TypeError("Expected argument 'enable_cluster_monitoring' to be a bool")
        __self__.enable_cluster_monitoring = enable_cluster_monitoring
        """
        (Computed) Enable built-in cluster monitoring. Default `false` (bool)
        """
        if enable_network_policy and not isinstance(enable_network_policy, bool):
            raise TypeError("Expected argument 'enable_network_policy' to be a bool")
        __self__.enable_network_policy = enable_network_policy
        """
        (Computed) Enable project network isolation. Default `false` (bool)
        """
        if gke_config and not isinstance(gke_config, dict):
            raise TypeError("Expected argument 'gke_config' to be a dict")
        __self__.gke_config = gke_config
        """
        (Computed) The Google gke configuration for `gke` Clusters. Conflicts with `aks_config`, `eks_config` and `rke_config` (list maxitems:1)
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if k3s_config and not isinstance(k3s_config, dict):
            raise TypeError("Expected argument 'k3s_config' to be a dict")
        __self__.k3s_config = k3s_config
        """
        (Computed) The K3S configuration for `k3s` imported Clusters. Conflicts with `aks_config`, `eks_config`, `gke_config` and `rke_config` (list maxitems:1)
        """
        if kube_config and not isinstance(kube_config, str):
            raise TypeError("Expected argument 'kube_config' to be a str")
        __self__.kube_config = kube_config
        """
        (Computed) Kube Config generated for the cluster (string)
        """
        if labels and not isinstance(labels, dict):
            raise TypeError("Expected argument 'labels' to be a dict")
        __self__.labels = labels
        """
        (Computed) Labels for Node Pool object (map)
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if rke_config and not isinstance(rke_config, dict):
            raise TypeError("Expected argument 'rke_config' to be a dict")
        __self__.rke_config = rke_config
        """
        (Computed) The RKE configuration for `rke` Clusters. Conflicts with `aks_config`, `eks_config` and `gke_config` (list maxitems:1)
        """
        if scheduled_cluster_scans and not isinstance(scheduled_cluster_scans, list):
            raise TypeError("Expected argument 'scheduled_cluster_scans' to be a list")
        __self__.scheduled_cluster_scans = scheduled_cluster_scans
        if system_project_id and not isinstance(system_project_id, str):
            raise TypeError("Expected argument 'system_project_id' to be a str")
        __self__.system_project_id = system_project_id
        """
        (Computed) System project ID for the cluster (string)
        """
class AwaitableGetClusterResult(GetClusterResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetClusterResult(
            aks_config=self.aks_config,
            annotations=self.annotations,
            cluster_auth_endpoint=self.cluster_auth_endpoint,
            cluster_monitoring_input=self.cluster_monitoring_input,
            cluster_registration_token=self.cluster_registration_token,
            cluster_template_answers=self.cluster_template_answers,
            cluster_template_id=self.cluster_template_id,
            cluster_template_questions=self.cluster_template_questions,
            cluster_template_revision_id=self.cluster_template_revision_id,
            default_pod_security_policy_template_id=self.default_pod_security_policy_template_id,
            default_project_id=self.default_project_id,
            description=self.description,
            driver=self.driver,
            eks_config=self.eks_config,
            enable_cluster_alerting=self.enable_cluster_alerting,
            enable_cluster_monitoring=self.enable_cluster_monitoring,
            enable_network_policy=self.enable_network_policy,
            gke_config=self.gke_config,
            id=self.id,
            k3s_config=self.k3s_config,
            kube_config=self.kube_config,
            labels=self.labels,
            name=self.name,
            rke_config=self.rke_config,
            scheduled_cluster_scans=self.scheduled_cluster_scans,
            system_project_id=self.system_project_id)

def get_cluster(name=None,opts=None):
    """
    Use this data source to retrieve information about a Rancher v2 cluster.




    :param str name: The name of the Cluster (string)
    """
    __args__ = dict()


    __args__['name'] = name
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('rancher2:index/getCluster:getCluster', __args__, opts=opts).value

    return AwaitableGetClusterResult(
        aks_config=__ret__.get('aksConfig'),
        annotations=__ret__.get('annotations'),
        cluster_auth_endpoint=__ret__.get('clusterAuthEndpoint'),
        cluster_monitoring_input=__ret__.get('clusterMonitoringInput'),
        cluster_registration_token=__ret__.get('clusterRegistrationToken'),
        cluster_template_answers=__ret__.get('clusterTemplateAnswers'),
        cluster_template_id=__ret__.get('clusterTemplateId'),
        cluster_template_questions=__ret__.get('clusterTemplateQuestions'),
        cluster_template_revision_id=__ret__.get('clusterTemplateRevisionId'),
        default_pod_security_policy_template_id=__ret__.get('defaultPodSecurityPolicyTemplateId'),
        default_project_id=__ret__.get('defaultProjectId'),
        description=__ret__.get('description'),
        driver=__ret__.get('driver'),
        eks_config=__ret__.get('eksConfig'),
        enable_cluster_alerting=__ret__.get('enableClusterAlerting'),
        enable_cluster_monitoring=__ret__.get('enableClusterMonitoring'),
        enable_network_policy=__ret__.get('enableNetworkPolicy'),
        gke_config=__ret__.get('gkeConfig'),
        id=__ret__.get('id'),
        k3s_config=__ret__.get('k3sConfig'),
        kube_config=__ret__.get('kubeConfig'),
        labels=__ret__.get('labels'),
        name=__ret__.get('name'),
        rke_config=__ret__.get('rkeConfig'),
        scheduled_cluster_scans=__ret__.get('scheduledClusterScans'),
        system_project_id=__ret__.get('systemProjectId'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetClusterDriverResult:
    """
    A collection of values returned by getClusterDriver.
    """
    def __init__(__self__, active=None, actual_url=None, annotations=None, builtin=None, checksum=None, id=None, labels=None, name=None, ui_url=None, url=None, whitelist_domains=None):
        if active and not isinstance(active, bool):
            raise TypeError("Expected argument 'active' to be a bool")
        __self__.active = active
        """
        (Computed) Specify if the cluster driver state (bool)
        """
        if actual_url and not isinstance(actual_url, str):
            raise TypeError("Expected argument 'actual_url' to be a str")
        __self__.actual_url = actual_url
        """
        (Computed) Actual url of the cluster driver (string)
        """
        if annotations and not isinstance(annotations, dict):
            raise TypeError("Expected argument 'annotations' to be a dict")
        __self__.annotations = annotations
        """
        (Computed) Annotations of the resource (map)
        """
        if builtin and not isinstance(builtin, bool):
            raise TypeError("Expected argument 'builtin' to be a bool")
        __self__.builtin = builtin
        """
        (Computed) Specify whether the cluster driver is an internal cluster driver or not (bool)
        """
        if checksum and not isinstance(checksum, str):
            raise TypeError("Expected argument 'checksum' to be a str")
        __self__.checksum = checksum
        """
        (Computed) Verify that the downloaded driver matches the expected checksum (string)
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if labels and not isinstance(labels, dict):
            raise TypeError("Expected argument 'labels' to be a dict")
        __self__.labels = labels
        """
        (Computed) Labels of the resource (map)
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if ui_url and not isinstance(ui_url, str):
            raise TypeError("Expected argument 'ui_url' to be a str")
        __self__.ui_url = ui_url
        """
        (Computed) The URL to load for customized Add Clusters screen for this driver (string)
        """
        if url and not isinstance(url, str):
            raise TypeError("Expected argument 'url' to be a str")
        __self__.url = url
        if whitelist_domains and not isinstance(whitelist_domains, list):
            raise TypeError("Expected argument 'whitelist_domains' to be a list")
        __self__.whitelist_domains = whitelist_domains
        """
        (Computed) Domains to whitelist for the ui (list)
        """
class AwaitableGetClusterDriverResult(GetClusterDriverResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetClusterDriverResult(
            active=self.active,
            actual_url=self.actual_url,
            annotations=self.annotations,
            builtin=self.builtin,
            checksum=self.checksum,
            id=self.id,
            labels=self.labels,
            name=self.name,
            ui_url=self.ui_url,
            url=self.url,
            whitelist_domains=self.whitelist_domains)

def get_cluster_driver(name=None,url=None,opts=None):
    """
    Use this data source to retrieve information about a Rancher v2 Cluster Driver resource.




    :param str name: Name of the cluster driver (string)
    :param str url: The URL to download the machine driver binary for 64-bit Linux (string)
    """
    __args__ = dict()


    __args__['name'] = name
    __args__['url'] = url
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('rancher2:index/getClusterDriver:getClusterDriver', __args__, opts=opts).value

    return AwaitableGetClusterDriverResult(
        active=__ret__.get('active'),
        actual_url=__ret__.get('actualUrl'),
        annotations=__ret__.get('annotations'),
        builtin=__ret__.get('builtin'),
        checksum=__ret__.get('checksum'),
        id=__ret__.get('id'),
        labels=__ret__.get('labels'),
        name=__ret__.get('name'),
        ui_url=__ret__.get('uiUrl'),
        url=__ret__.get('url'),
        whitelist_domains=__ret__.get('whitelistDomains'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetCloudCredentialResult:
    """
    A collection of values returned by getCloudCredential.
    """
    def __init__(__self__, annotations=None, id=None, labels=None, name=None):
        if annotations and not isinstance(annotations, dict):
            raise TypeError("Expected argument 'annotations' to be a dict")
        __self__.annotations = annotations
        """
        (Computed) Annotations for the Cloud Credential (map)
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if labels and not isinstance(labels, dict):
            raise TypeError("Expected argument 'labels' to be a dict")
        __self__.labels = labels
        """
        (Computed) Labels for the Cloud Credential (map)
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
class AwaitableGetCloudCredentialResult(GetCloudCredentialResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCloudCredentialResult(
            annotations=self.annotations,
            id=self.id,
            labels=self.labels,
            name=self.name)

def get_cloud_credential(name=None,opts=None):
    """
    Use this data source to retrieve information about a Rancher v2 Cloud Credential.




    :param str name: The Cloud Credential name.
    """
    __args__ = dict()


    __args__['name'] = name
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('rancher2:index/getCloudCredential:getCloudCredential', __args__, opts=opts).value

    return AwaitableGetCloudCredentialResult(
        annotations=__ret__.get('annotations'),
        id=__ret__.get('id'),
        labels=__ret__.get('labels'),
        name=__ret__.get('name'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetPodSecurityPolicyTemplateResult:
    """
    A collection of values returned by getPodSecurityPolicyTemplate.
    """
    def __init__(__self__, allow_privilege_escalation=None, allowed_capabilities=None, allowed_csi_drivers=None, allowed_flex_volumes=None, allowed_host_paths=None, allowed_proc_mount_types=None, allowed_unsafe_sysctls=None, annotations=None, default_add_capabilities=None, default_allow_privilege_escalation=None, description=None, forbidden_sysctls=None, fs_group=None, host_ipc=None, host_network=None, host_pid=None, host_ports=None, id=None, labels=None, name=None, privileged=None, read_only_root_filesystem=None, required_drop_capabilities=None, run_as_group=None, run_as_user=None, runtime_class=None, se_linux=None, supplemental_group=None, volumes=None):
        if allow_privilege_escalation and not isinstance(allow_privilege_escalation, bool):
            raise TypeError("Expected argument 'allow_privilege_escalation' to be a bool")
        __self__.allow_privilege_escalation = allow_privilege_escalation
        if allowed_capabilities and not isinstance(allowed_capabilities, list):
            raise TypeError("Expected argument 'allowed_capabilities' to be a list")
        __self__.allowed_capabilities = allowed_capabilities
        if allowed_csi_drivers and not isinstance(allowed_csi_drivers, list):
            raise TypeError("Expected argument 'allowed_csi_drivers' to be a list")
        __self__.allowed_csi_drivers = allowed_csi_drivers
        if allowed_flex_volumes and not isinstance(allowed_flex_volumes, list):
            raise TypeError("Expected argument 'allowed_flex_volumes' to be a list")
        __self__.allowed_flex_volumes = allowed_flex_volumes
        if allowed_host_paths and not isinstance(allowed_host_paths, list):
            raise TypeError("Expected argument 'allowed_host_paths' to be a list")
        __self__.allowed_host_paths = allowed_host_paths
        if allowed_proc_mount_types and not isinstance(allowed_proc_mount_types, list):
            raise TypeError("Expected argument 'allowed_proc_mount_types' to be a list")
        __self__.allowed_proc_mount_types = allowed_proc_mount_types
        if allowed_unsafe_sysctls and not isinstance(allowed_unsafe_sysctls, list):
            raise TypeError("Expected argument 'allowed_unsafe_sysctls' to be a list")
        __self__.allowed_unsafe_sysctls = allowed_unsafe_sysctls
        if annotations and not isinstance(annotations, dict):
            raise TypeError("Expected argument 'annotations' to be a dict")
        __self__.annotations = annotations
        if default_add_capabilities and not isinstance(default_add_capabilities, list):
            raise TypeError("Expected argument 'default_add_capabilities' to be a list")
        __self__.default_add_capabilities = default_add_capabilities
        if default_allow_privilege_escalation and not isinstance(default_allow_privilege_escalation, bool):
            raise TypeError("Expected argument 'default_allow_privilege_escalation' to be a bool")
        __self__.default_allow_privilege_escalation = default_allow_privilege_escalation
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        __self__.description = description
        if forbidden_sysctls and not isinstance(forbidden_sysctls, list):
            raise TypeError("Expected argument 'forbidden_sysctls' to be a list")
        __self__.forbidden_sysctls = forbidden_sysctls
        if fs_group and not isinstance(fs_group, dict):
            raise TypeError("Expected argument 'fs_group' to be a dict")
        __self__.fs_group = fs_group
        if host_ipc and not isinstance(host_ipc, bool):
            raise TypeError("Expected argument 'host_ipc' to be a bool")
        __self__.host_ipc = host_ipc
        if host_network and not isinstance(host_network, bool):
            raise TypeError("Expected argument 'host_network' to be a bool")
        __self__.host_network = host_network
        if host_pid and not isinstance(host_pid, bool):
            raise TypeError("Expected argument 'host_pid' to be a bool")
        __self__.host_pid = host_pid
        if host_ports and not isinstance(host_ports, list):
            raise TypeError("Expected argument 'host_ports' to be a list")
        __self__.host_ports = host_ports
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if labels and not isinstance(labels, dict):
            raise TypeError("Expected argument 'labels' to be a dict")
        __self__.labels = labels
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if privileged and not isinstance(privileged, bool):
            raise TypeError("Expected argument 'privileged' to be a bool")
        __self__.privileged = privileged
        if read_only_root_filesystem and not isinstance(read_only_root_filesystem, bool):
            raise TypeError("Expected argument 'read_only_root_filesystem' to be a bool")
        __self__.read_only_root_filesystem = read_only_root_filesystem
        if required_drop_capabilities and not isinstance(required_drop_capabilities, list):
            raise TypeError("Expected argument 'required_drop_capabilities' to be a list")
        __self__.required_drop_capabilities = required_drop_capabilities
        if run_as_group and not isinstance(run_as_group, dict):
            raise TypeError("Expected argument 'run_as_group' to be a dict")
        __self__.run_as_group = run_as_group
        if run_as_user and not isinstance(run_as_user, dict):
            raise TypeError("Expected argument 'run_as_user' to be a dict")
        __self__.run_as_user = run_as_user
        if runtime_class and not isinstance(runtime_class, dict):
            raise TypeError("Expected argument 'runtime_class' to be a dict")
        __self__.runtime_class = runtime_class
        if se_linux and not isinstance(se_linux, dict):
            raise TypeError("Expected argument 'se_linux' to be a dict")
        __self__.se_linux = se_linux
        if supplemental_group and not isinstance(supplemental_group, dict):
            raise TypeError("Expected argument 'supplemental_group' to be a dict")
        __self__.supplemental_group = supplemental_group
        if volumes and not isinstance(volumes, list):
            raise TypeError("Expected argument 'volumes' to be a list")
        __self__.volumes = volumes
class AwaitableGetPodSecurityPolicyTemplateResult(GetPodSecurityPolicyTemplateResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPodSecurityPolicyTemplateResult(
            allow_privilege_escalation=self.allow_privilege_escalation,
            allowed_capabilities=self.allowed_capabilities,
            allowed_csi_drivers=self.allowed_csi_drivers,
            allowed_flex_volumes=self.allowed_flex_volumes,
            allowed_host_paths=self.allowed_host_paths,
            allowed_proc_mount_types=self.allowed_proc_mount_types,
            allowed_unsafe_sysctls=self.allowed_unsafe_sysctls,
            annotations=self.annotations,
            default_add_capabilities=self.default_add_capabilities,
            default_allow_privilege_escalation=self.default_allow_privilege_escalation,
            description=self.description,
            forbidden_sysctls=self.forbidden_sysctls,
            fs_group=self.fs_group,
            host_ipc=self.host_ipc,
            host_network=self.host_network,
            host_pid=self.host_pid,
            host_ports=self.host_ports,
            id=self.id,
            labels=self.labels,
            name=self.name,
            privileged=self.privileged,
            read_only_root_filesystem=self.read_only_root_filesystem,
            required_drop_capabilities=self.required_drop_capabilities,
            run_as_group=self.run_as_group,
            run_as_user=self.run_as_user,
            runtime_class=self.runtime_class,
            se_linux=self.se_linux,
            supplemental_group=self.supplemental_group,
            volumes=self.volumes)

def get_pod_security_policy_template(allow_privilege_escalation=None,allowed_capabilities=None,allowed_csi_drivers=None,allowed_flex_volumes=None,allowed_host_paths=None,allowed_proc_mount_types=None,allowed_unsafe_sysctls=None,annotations=None,default_add_capabilities=None,default_allow_privilege_escalation=None,description=None,forbidden_sysctls=None,fs_group=None,host_ipc=None,host_network=None,host_pid=None,host_ports=None,labels=None,name=None,privileged=None,read_only_root_filesystem=None,required_drop_capabilities=None,run_as_group=None,run_as_user=None,runtime_class=None,se_linux=None,supplemental_group=None,volumes=None,opts=None):
    """
    Use this data source to retrieve information about a Rancher v2 PodSecurityPolicyTemplate.




    :param bool allow_privilege_escalation: = (Optional)
    :param list allowed_capabilities: (list)
    :param list allowed_csi_drivers: (list)
    :param list allowed_flex_volumes: (list)
    :param list allowed_host_paths: (list)
    :param list allowed_proc_mount_types: (list)
    :param list allowed_unsafe_sysctls: (list)
    :param dict annotations: Annotations for PodSecurityPolicyTemplate object (map)
    :param list default_add_capabilities: (list)
    :param bool default_allow_privilege_escalation: (list)
    :param str description: The PodSecurityPolicyTemplate description (string)
    :param list forbidden_sysctls: (list)
    :param dict fs_group: (list maxitems:1)
    :param bool host_ipc: (bool)
    :param bool host_pid: (bool)
    :param list host_ports: (list)
    :param dict labels: Labels for PodSecurityPolicyTemplate object (map)
    :param str name: The name of the PodSecurityPolicyTemplate (string)
    :param bool privileged: (bool)
    :param bool read_only_root_filesystem: (bool)
    :param list required_drop_capabilities: (list)
    :param dict run_as_group: (list maxitems:1)
    :param dict run_as_user: (list maxitems:1)
    :param dict runtime_class: (list maxitems:1)
    :param dict se_linux: (list maxitems:1)
    :param dict supplemental_group: (list maxitems:1)
    :param list volumes: (list)

    The **allowed_csi_drivers** object supports the following:

      * `name` (`str`) - The name of the PodSecurityPolicyTemplate (string)

    The **allowed_flex_volumes** object supports the following:

      * `driver` (`str`)

    The **allowed_host_paths** object supports the following:

      * `pathPrefix` (`str`)
      * `readOnly` (`bool`)

    The **fs_group** object supports the following:

      * `ranges` (`list`)
        * `max` (`float`)
        * `min` (`float`)

      * `rule` (`str`)

    The **host_ports** object supports the following:

      * `max` (`float`)
      * `min` (`float`)

    The **run_as_group** object supports the following:

      * `ranges` (`list`)
        * `max` (`float`)
        * `min` (`float`)

      * `rule` (`str`)

    The **run_as_user** object supports the following:

      * `ranges` (`list`)
        * `max` (`float`)
        * `min` (`float`)

      * `rule` (`str`)

    The **runtime_class** object supports the following:

      * `allowedRuntimeClassNames` (`list`)
      * `defaultRuntimeClassName` (`str`)

    The **se_linux** object supports the following:

      * `rule` (`str`)
      * `seLinuxOption` (`dict`)
        * `level` (`str`)
        * `role` (`str`)
        * `type` (`str`)
        * `user` (`str`)

    The **supplemental_group** object supports the following:

      * `ranges` (`list`)
        * `max` (`float`)
        * `min` (`float`)

      * `rule` (`str`)
    """
    __args__ = dict()


    __args__['allowPrivilegeEscalation'] = allow_privilege_escalation
    __args__['allowedCapabilities'] = allowed_capabilities
    __args__['allowedCsiDrivers'] = allowed_csi_drivers
    __args__['allowedFlexVolumes'] = allowed_flex_volumes
    __args__['allowedHostPaths'] = allowed_host_paths
    __args__['allowedProcMountTypes'] = allowed_proc_mount_types
    __args__['allowedUnsafeSysctls'] = allowed_unsafe_sysctls
    __args__['annotations'] = annotations
    __args__['defaultAddCapabilities'] = default_add_capabilities
    __args__['defaultAllowPrivilegeEscalation'] = default_allow_privilege_escalation
    __args__['description'] = description
    __args__['forbiddenSysctls'] = forbidden_sysctls
    __args__['fsGroup'] = fs_group
    __args__['hostIpc'] = host_ipc
    __args__['hostNetwork'] = host_network
    __args__['hostPid'] = host_pid
    __args__['hostPorts'] = host_ports
    __args__['labels'] = labels
    __args__['name'] = name
    __args__['privileged'] = privileged
    __args__['readOnlyRootFilesystem'] = read_only_root_filesystem
    __args__['requiredDropCapabilities'] = required_drop_capabilities
    __args__['runAsGroup'] = run_as_group
    __args__['runAsUser'] = run_as_user
    __args__['runtimeClass'] = runtime_class
    __args__['seLinux'] = se_linux
    __args__['supplementalGroup'] = supplemental_group
    __args__['volumes'] = volumes
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('rancher2:index/getPodSecurityPolicyTemplate:getPodSecurityPolicyTemplate', __args__, opts=opts).value

    return AwaitableGetPodSecurityPolicyTemplateResult(
        allow_privilege_escalation=__ret__.get('allowPrivilegeEscalation'),
        allowed_capabilities=__ret__.get('allowedCapabilities'),
        allowed_csi_drivers=__ret__.get('allowedCsiDrivers'),
        allowed_flex_volumes=__ret__.get('allowedFlexVolumes'),
        allowed_host_paths=__ret__.get('allowedHostPaths'),
        allowed_proc_mount_types=__ret__.get('allowedProcMountTypes'),
        allowed_unsafe_sysctls=__ret__.get('allowedUnsafeSysctls'),
        annotations=__ret__.get('annotations'),
        default_add_capabilities=__ret__.get('defaultAddCapabilities'),
        default_allow_privilege_escalation=__ret__.get('defaultAllowPrivilegeEscalation'),
        description=__ret__.get('description'),
        forbidden_sysctls=__ret__.get('forbiddenSysctls'),
        fs_group=__ret__.get('fsGroup'),
        host_ipc=__ret__.get('hostIpc'),
        host_network=__ret__.get('hostNetwork'),
        host_pid=__ret__.get('hostPid'),
        host_ports=__ret__.get('hostPorts'),
        id=__ret__.get('id'),
        labels=__ret__.get('labels'),
        name=__ret__.get('name'),
        privileged=__ret__.get('privileged'),
        read_only_root_filesystem=__ret__.get('readOnlyRootFilesystem'),
        required_drop_capabilities=__ret__.get('requiredDropCapabilities'),
        run_as_group=__ret__.get('runAsGroup'),
        run_as_user=__ret__.get('runAsUser'),
        runtime_class=__ret__.get('runtimeClass'),
        se_linux=__ret__.get('seLinux'),
        supplemental_group=__ret__.get('supplementalGroup'),
        volumes=__ret__.get('volumes'))
